@@ -82,7 +82,7 @@ impl From<libusb::Error> for Error {
     }
 }
 
-/// Covert to our crate speed
+/// Convert to our crate speed
 impl From<libusb::Speed> for usb::Speed {
     fn from(libusb: libusb::Speed) -> Self {
         match libusb {
@@ -287,7 +287,7 @@ impl LibUsbProfiler {
                 );
                 let path = device_path.to_string();
 
-                let interface = usb::Interface {
+                let mut interface = usb::Interface {
                     name: get_sysfs_string(&path, "interface").or_else(|| {
                         interface_desc
                             .description_string_index()
@@ -302,6 +302,8 @@ impl LibUsbProfiler {
                     driver: get_sysfs_readlink(&path, "driver")
                         .or_else(|| get_udev_driver_name(&path).ok().flatten()),
                     syspath: get_syspath(&path).or_else(|| get_udev_syspath(&path).ok().flatten()),
+                    devpaths: None,
+                    mount_paths: None,
                     path,
                     length: interface_desc.length(),
                     endpoints: self.build_endpoints(handle, &device_path, &interface_desc),
@@ -321,6 +323,9 @@ impl LibUsbProfiler {
                     device_path: Some(device_path),
                 };
 
+                interface.devpaths = interface.dev_paths();
+                interface.mount_paths = interface.block_mount_paths();
+
                 ret.push(interface);
             }
         }
@@ -367,6 +372,14 @@ impl LibUsbProfiler {
                 None
             };
 
+            // The rusb crate multiplies the raw MaxPower value by 2, which is not correct
+            // for USB3 and later, so we need to multiply by 4 to get the correct number.
+            let power_mult = if device_desc.usb_version().0 >= 3 {
+                4
+            } else {
+                1
+            };
+
             ret.push(usb::Configuration {
                 name: config_desc
                     .description_string_index()
@@ -377,12 +390,13 @@ impl LibUsbProfiler {
                 number: config_desc.number(),
                 attributes,
                 max_power: NumericalUnit {
-                    value: config_desc.max_power() as u32,
+                    value: config_desc.max_power() as u32 * power_mult,
                     unit: String::from("mA"),
                     description: None,
                 },
                 length: config_desc.length(),
                 total_length: config_desc.total_length(),
+                num_interfaces: Some(config_desc.num_interfaces()),
                 interfaces: self.build_interfaces(handle, &config_desc)?,
                 extra: self
                     .build_config_descriptor_extra(handle, config_desc.extra().to_vec())
