@@ -64,7 +64,7 @@ impl From<Recipient> for nusb::transfer::Recipient {
     }
 }
 
-/// Covert to our crate speed
+/// Convert to our crate speed
 impl From<nusb::Speed> for usb::Speed {
     fn from(nusb: nusb::Speed) -> Self {
         match nusb {
@@ -271,7 +271,7 @@ impl UsbDevice {
             },
             _ => Error {
                 kind: ErrorKind::Nusb,
-                message: format!("Failed to get control message: {}", e),
+                message: format!("Failed to get control message: {e}"),
             },
         })
     }
@@ -285,11 +285,11 @@ impl UsbDevice {
                 ..
             }) => self.control_in(control_request, true).map_err(|e| Error {
                 kind: ErrorKind::Nusb,
-                message: format!("Failed to get control message: {}", e),
+                message: format!("Failed to get control message: {e}"),
             }),
             Err(e) => Err(Error {
                 kind: ErrorKind::Nusb,
-                message: format!("Failed to get control message: {}", e),
+                message: format!("Failed to get control message: {e}"),
             }),
         }
     }
@@ -369,7 +369,7 @@ impl NusbProfiler {
                 transfer_type: usb::TransferType::from(endpoint.attributes()),
                 sync_type: usb::SyncType::from(endpoint.attributes()),
                 usage_type: usb::UsageType::from(endpoint.attributes()),
-                max_packet_size: endpoint.max_packet_size() as u16,
+                max_packet_size: endpoint.max_packet_size_raw(),
                 interval: endpoint.interval(),
                 length: endpoint_desc[0],
                 extra: self
@@ -409,6 +409,7 @@ impl NusbProfiler {
                     Some(interface_alt.alternate_setting()),
                 );
                 let path = device_path.to_string();
+                let syspath = get_syspath(&path).or_else(|| get_udev_syspath(&path).ok().flatten());
 
                 let interface_desc = interface_alt.as_bytes();
                 let interface_extra = interface_alt
@@ -418,7 +419,7 @@ impl NusbProfiler {
                     .flat_map(|d| d.to_vec())
                     .collect::<Vec<u8>>();
 
-                let interface = usb::Interface {
+                let mut interface = usb::Interface {
                     name: get_sysfs_string(&path, "interface").or_else(|| {
                         interface_alt
                             .string_index()
@@ -432,7 +433,9 @@ impl NusbProfiler {
                     alt_setting: interface_alt.alternate_setting(),
                     driver: get_sysfs_readlink(&path, "driver")
                         .or_else(|| get_udev_driver_name(&path).ok().flatten()),
-                    syspath: get_syspath(&path).or_else(|| get_udev_syspath(&path).ok().flatten()),
+                    syspath,
+                    devpaths: None,
+                    mount_paths: None,
                     length: interface_desc[0],
                     endpoints: self.build_endpoints(device, &device_path, &interface_alt),
                     extra: self
@@ -452,6 +455,25 @@ impl NusbProfiler {
                     internal: InternalData::default(),
                 };
 
+                interface.devpaths = interface.dev_paths();
+                interface.mount_paths = interface.block_mount_paths();
+                // TODO add to device?
+                // if let Some(devpaths) = &interface.devpaths {
+                //     let ids: Vec<_> = devpaths
+                //         .iter()
+                //         .filter_map(|p| {
+                //             let path = format!(
+                //                 "{}/{}/{}",
+                //                 interface.sysfs_name(),
+                //                 "tty",
+                //                 p.file_name()?.to_string_lossy()
+                //             );
+                //             get_devlinks(&path).ok().flatten()
+                //         })
+                //         .collect();
+                //     log::info!("Interface {} devlinks: {:?}", interface.path, ids);
+                // }
+
                 ret.push(interface);
             }
         }
@@ -459,7 +481,11 @@ impl NusbProfiler {
         Ok(ret)
     }
 
-    fn build_configurations(&self, device: &UsbDevice) -> Result<Vec<usb::Configuration>> {
+    fn build_configurations(
+        &self,
+        device: &UsbDevice,
+        device_desc: &usb::DeviceDescriptor,
+    ) -> Result<Vec<usb::Configuration>> {
         let mut ret: Vec<usb::Configuration> = Vec::new();
 
         for c in device.handle.configurations() {
@@ -485,6 +511,14 @@ impl NusbProfiler {
                 .collect::<Vec<u8>>();
             let total_length = u16::from_le_bytes(config_desc[2..4].try_into().unwrap());
 
+            // nusb returns MaxPower as the raw descriptor value.
+            // Raw MaxPower number is supplied in 8mA units for USB >= 3, otherwise 2mA.
+            let power_mult = if device_desc.usb_version.major() >= 3 {
+                8
+            } else {
+                2
+            };
+
             ret.push(usb::Configuration {
                 name: c
                     .string_index()
@@ -494,13 +528,13 @@ impl NusbProfiler {
                 number: c.configuration_value(),
                 attributes,
                 max_power: NumericalUnit {
-                    // *2 because nusb returns in 2mA units
-                    value: (c.max_power() as u32 * 2),
+                    value: (c.max_power() as u32 * power_mult),
                     unit: String::from("mA"),
                     description: None,
                 },
-                length: config_desc.len() as u8,
+                length: config_desc[0],
                 total_length,
+                num_interfaces: Some(c.num_interfaces()),
                 interfaces: self.build_interfaces(device, &c)?,
                 extra: self
                     .build_config_descriptor_extra(device, config_extra)
@@ -568,7 +602,7 @@ impl NusbProfiler {
                         .map(|v| v.name().to_owned())
                 },
             ),
-            configurations: self.build_configurations(device)?,
+            configurations: self.build_configurations(device, &device_desc)?,
             status: Self::get_device_status(device).ok(),
             debug: Self::get_debug_descriptor(device).ok(),
             binary_object_store: None,
@@ -610,7 +644,7 @@ impl NusbProfiler {
 
         let generic_extra = |sysfs_name: &str| {
             usb::DeviceExtra {
-                max_packet_size: device_info.max_packet_size_0(),
+                max_packet_size: 0, // ...extra will update with actual
                 // nusb doesn't have these cached
                 string_indexes: (0, 0, 0),
                 driver: get_sysfs_readlink(sysfs_name, "driver")
@@ -667,7 +701,7 @@ impl NusbProfiler {
                         }
                         Err(e) => {
                             sp_device.extra = Some(generic_extra(&sp_device.sysfs_name()));
-                            Some(format!("Failed to get some extra data for {}, probably requires elevated permissions: {}", sp_device, e))
+                            Some(format!("Failed to get some extra data for {sp_device}, probably requires elevated permissions: {e}"))
                         }
                     }
                 };
@@ -712,13 +746,13 @@ impl Profiler<UsbDevice> for NusbProfiler {
                     // print any non-critical error during extra capture
                     sp_device.profiler_error.iter().for_each(|e| {
                         if print_stderr {
-                            eprintln!("{}", e);
+                            eprintln!("{e}");
                         } else {
-                            log::warn!("Non-critical error during profile of {:?}: {}", device, e);
+                            log::warn!("Non-critical error during profile of {device:?}: {e}");
                         }
                     });
                 }
-                Err(e) => eprintln!("Failed to get data for {:?}: {}", device, e),
+                Err(e) => eprintln!("Failed to get data for {device:?}: {e}"),
             }
         }
 
@@ -738,8 +772,7 @@ impl Profiler<UsbDevice> for NusbProfiler {
                         return Err(Error::new(
                             ErrorKind::InvalidDevice,
                             &format!(
-                                "Device {} returned by nusb::list_root_hubs is not a root hub!",
-                                sp_device
+                                "Device {sp_device} returned by nusb::list_root_hubs is not a root hub!"
                             ),
                         ));
                     }
@@ -749,15 +782,15 @@ impl Profiler<UsbDevice> for NusbProfiler {
                     // print any non-critical error during extra capture
                     sp_device.profiler_error.iter().for_each(|e| {
                         if print_stderr {
-                            eprintln!("{}", e);
+                            eprintln!("{e}");
                         } else {
-                            log::warn!("Non-critical error during profile of {}: {}", sp_device, e);
+                            log::warn!("Non-critical error during profile of {sp_device}: {e}");
                         }
                     });
 
                     root_hubs.insert(sp_device.location_id.bus, sp_device);
                 }
-                Err(e) => eprintln!("Failed to get data for {:?}: {}", device, e),
+                Err(e) => eprintln!("Failed to get data for {device:?}: {e}"),
             }
         }
 
